@@ -2,7 +2,7 @@ from .base import Address, Person  # noqa
 from .bank_account import BankAccount  # noqa
 from .buyer import Buyer  # noqa
 from .card import Card  # noqa
-from .invoice import Invoice, BillingConfiguration, BillingInstructions  # noqa
+from .invoice import Invoice, BillingInstructions, Fine, Interest, Discount  # noqa
 from .seller import Seller  # noqa
 from .token import Token  # noqa
 from .transaction import Transaction, Source, InstallmentPlan  # noqa
